package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````)14``#0```!H@0````0`!30`(``(
M`"@`%P`6``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!@````8````!`````$````!````````````````````V'H`
M`-AZ```%`````!````$```#,?0``S(T``,R-``!X`@``I`(```8`````$```
M`@```-1]``#4C0``U(T``/````#P````!@````0````$````3`$``$P!``!,
M`0``)````"0````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9,Q]``#,C0``S(T``#0"```T`@``!`````$````O;&EB+VQD
M+6UU<VPM87)M:&8N<V\N,0`$````%`````,```!'3E4`.QW^T#FG=BU85+!B
MB5H515JF]601````3`````@````(`````9`0`"5`!(`H@!`%H(90A("!``(+
M(`2-.(`208H$"`A,````30```%$```!6````5P```%\```!@````80``````
M``!C````9`````````!E````9@```&D```````````````&O-.AJ?YI\ZM/O
M#L[>1RUOQ=\?+L6;MKB-\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MO
M0OK7A^)'Q@%8[Y=YF$_#F[OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_
MJ9R;X*<""FH:GE"_VE<;H^#[20``````````````````````````6!``````
M```#``@```````"0`````````P`2``$``````````````!(````)````````
M```````2````$```````````````$0```.T!`````````````!$```!V`0``
M```````````2````%P``````````````$@```,8!`````````````!(````?
M```````````````2`````@,`````````````$@```/H!`````````````!(`
M``#2`0`````````````2````)@``````````````(`````T#````````````
M`"$````^```````````````2````1```````````````$@```$L`````````
M`````!(```##`@`````````````2````V0(`````````````$@```%(`````
M`````````!(````5`@`````````````2````60``````````````$@```)L"
M`````````````!(```!@```````````````2````:```````````````$@``
M`+P"`````````````!(```!P```````````````2````A`(`````````````
M$@```'@``````````````!(```"!```````````````@````T@(`````````
M````$@```)T``````````````!(```"B```````````````2````DP$`````
M````````%@```*("`````````````!(```!"`@`````````````2````JP``
M````````````$@```#0"`````````````!(```!1`P`````````````2````
MK0(`````````````$0````P#`````````````!$```!F`@`````````````2
M````\`(`````````````$@````X#`````````````!$```"R````````````
M```2````NP``````````````$0```(0!`````````````!(```#-````````
M```````B````W```````````````(````/(``````````````!(```"C````
M```````````2````4@(`````````````$@```/<``````````````"````"/
M`@`````````````2````$0$`````````````$@```+<!`````````````!(`
M```6`0`````````````2````=`(`````````````$@```!P!````````````
M`!(```"F`0`````````````2````*@$`````````````$@```#L!````````
M`````!(````0`@`````````````2````(0(`````````````$@```$$!````
M`````````!(```!;`@`````````````2````RP(`````````````$@```.@"
M`````````````!(```!0`0`````````````2````"P(`````````````$@``
M`%<!`````````````!(```!>`0`````````````2````"P,`````````````
M(0```&\!`````````````!(```!9!```<)`````````0`!,`_0(``$D3``#<
M`0``$@`*`.<!``#I.````@```!(`"P"3`P``124``*@$```2``H`:00``/DK
M``#,````$@`*`'`#``"]&P``!````!(`"@`-!```61````(````2``@`M@,`
M`.TI```,`@``$@`*`!,$``!$D````````!``$P!!!```P1L``,@!```2``H`
M[@,``$20````````$``3`($#``"%)```P````!(`"@"@`P``A1H``$@````2
M``H`J`,``&TB``!L````$@`*`,P#```!-P``&`$``!(`"@#A`P``B1T``"0`
M```2``H`^@,``'"0````````$``3``($``#9(@``4````!(`"@!D!```<)``
M```````0`!,`-@,``$$5``!$````$@`*`"$$``"M'0``&`$``!(`"@#7`P``
M0)````0````1`!(`.@0``$20````````$``2`/,#```E%0```````!(`"@`*
M!```?38``(0````2``H`/P,``&DD```<````$@`*`%H#``#-&@``\````!(`
M"@!.!```&3@``,X````2``H`6`0``'"0````````$``3`"T$``#%'@``J`,`
M`!(`"@``;W!E;F1I<@!M96UC;7``<W1D97)R`')E86QL;V,`86-C97-S`%]?
M9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``;65M
M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``<W1R<F-H<@!C;&]S961I<@!?
M251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!V9G!R:6YT9@!S=')C
M:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`
M7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A
M=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!M96UC<'D`<W1R;&5N`%]?<W1A
M8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C
M;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`7V9I
M;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E
M<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E
M<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U
M8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L
M;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``<W1R8W!Y`')E861D:7(`
M<W1R=&]K`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!S<')I;G1F`%]?;&EB8U]S
M=&%R=%]M86EN`'-N<')I;G1F`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C
M+FUU<VPM87)M=C<N<V\N,0!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE
M8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY
M7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`7U]E;F1?7P!P87)?
M9&EE`'-H85]I;FET`%]?8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN
M:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N
M9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L
M+T-/4D4``,R-```7````T(T``!<```"\CP``%P```,B/```7````U(\``!<`
M````D```%P```!"0```7````%)```!<````<D```%P```""0```7````))``
M`!<````HD```%P```"R0```7````-)```!<````XD```%P```$"0```7````
MP(\``!4%``#$CP``%08``,R/```5#@``T(\``!4?``#8CP``$R,``-R/```5
M*0``X(\``!4M``#DCP``%2\``.B/```5,0``[(\``!4R``#PCP``%38``/2/
M```5.P``^(\``!4]``#\CP``%4$``-".```6`P``U(X``!8$``#8C@``%@<`
M`-R.```6"```X(X``!8)``#DC@``%@H``.B.```6"P``[(X``!8,``#PC@``
M%@T``/2.```6#@``^(X``!80``#\C@``%A$```"/```6$@``!(\``!83```(
MCP``%A0```R/```6%0``$(\``!86```4CP``%A<``!B/```6&```'(\``!89
M```@CP``%AH``"2/```6&P``*(\``!8<```LCP``%AT``#"/```6'@``-(\`
M`!8@```XCP``%B$``#R/```6(@``0(\``!8D``!$CP``%B4``$B/```6)@``
M3(\``!8G``!0CP``%B@``%2/```6*P``6(\``!8L``!<CP``%BX``&"/```6
M,```9(\``!8Q``!HCP``%C(``&R/```6,P``<(\``!8T``!TCP``%C4``'B/
M```6-P``?(\``!8X``"`CP``%CD``(2/```6.@``B(\``!8\``",CP``%CX`
M`)"/```6/P``E(\``!9```"8CP``%D(``)R/```60P``H(\``!9$``"DCP``
M%D4``*B/```61@``K(\``!9'``"PCP``%D@``+2/```620``N(\``!9+```!
MM;WH`4!P1P3@+>4$X)_E#N"/X`CPON54?@```,:/X@?*C.)4_KSE`,:/X@?*
MC.),_KSE`,:/X@?*C.)$_KSE`,:/X@?*C.(\_KSE`,:/X@?*C.(T_KSE`,:/
MX@?*C.(L_KSE`,:/X@?*C.(D_KSE`,:/X@?*C.(<_KSE`,:/X@?*C.(4_KSE
M`,:/X@?*C.(,_KSE`,:/X@?*C.($_KSE`,:/X@?*C.+\_;SE`,:/X@?*C.+T
M_;SE`,:/X@?*C.+L_;SE`,:/X@?*C.+D_;SE`,:/X@?*C.+<_;SE`,:/X@?*
MC.+4_;SE`,:/X@?*C.+,_;SE`,:/X@?*C.+$_;SE`,:/X@?*C.*\_;SE`,:/
MX@?*C.*T_;SE`,:/X@?*C.*L_;SE`,:/X@?*C.*D_;SE`,:/X@?*C.*<_;SE
M`,:/X@?*C.*4_;SE>$?]YP#&C^('RHSBB/V\Y0#&C^('RHSB@/V\Y0#&C^('
MRHSB>/V\Y0#&C^('RHSB</V\Y0#&C^('RHSB:/V\Y0#&C^('RHSB8/V\Y0#&
MC^('RHSB6/V\Y0#&C^('RHSB4/V\Y0#&C^('RHSB2/V\Y0#&C^('RHSB0/V\
MY0#&C^('RHSB./V\Y0#&C^('RHSB,/V\Y0#&C^('RHSB*/V\Y0#&C^('RHSB
M(/V\Y0#&C^('RHSB&/V\Y0#&C^('RHSB$/V\Y0#&C^('RHSB"/V\Y0#&C^('
MRHSB`/V\Y0#&C^('RHSB^/R\Y0#&C^('RHSB\/R\Y0#&C^('RHSBZ/R\Y0#&
MC^('RHSBX/R\Y0#&C^('RHSBV/R\Y0#&C^('RHSBT/R\Y7A'_><`QH_B!\J,
MXL3\O.4`QH_B!\J,XKS\O.5X1_WG`,:/X@?*C.*P_+SE`,:/X@?*C.*H_+SE
M`,:/X@?*C.*@_+SE`,:/X@?*C.*8_+SE`,:/X@?*C.*0_+SE`,:/X@?*C.*(
M_+SE`,:/X@?*C.*`_+SE`,:/X@?*C.)X_+SE`````$_T@%SPM:WK#`S,^,`/
MB[#-Z08074U>2P62?43K6`:I!:H'J%M,&V@)DT_P``/_]UCO64I\1*)86$L#
MDN-8$4881@23__?&[E5+XU@=>``M9M`=[G`O2TL'F'M$&VC26,4<DOC^,P0P
M0_`#`[#Q@$^"^/XS=]*``/_W5N\#1DE*24QZ1-_X).'?^"3!%FC=Z082"&A\
M1/Y$_$0!*L/I``Z>8,/X#,!C8&7="!\#\0P,`.N"`%'X!$^(0DSX!$_YT=0<
M`"8[3SQ)?T3X:"I&`)9Y1$/X)&#_][3N`"@QT#=-"*Y]1.AH__?J[@1&-$@Q
M1GA$`/`C^4"S,DM[1-AH__=F[__W(.XP2B%+>D336!IH"9M:0$_P``,RT2!&
M"[#PO?_WKNXI2GI$T&`PL__W".\52QWN<"][1!MHTUB#^,Y6B>?X:/_WZN[)
MYZAH$+$!\*_[T><>2#%&>$0`\._XJ&``*,G0\^<;2QM(XUAX1!E&`Y/_]PSN
M!"2CYP$@__?"[O_W,.\R?```5GL``%Y[```@`0``1'L``#@!```T`0````$`
M`')\``"`?```KB@``+`H``!,?```[04``#)\``#X)0``&GP``&YZ``#N>P``
M+"4``!@!```8)P``3_``"T_P``X#27E$:$8@\`\,Y48`\`+XHG@``!"U`"0"
M1@M)"TAY1`A8A+`*2P*0RUC?^"C``Y,!E%'X#!`#1@"1`YA2^`0;__=0[@2P
M$+UV>0``$`$``/@````$`0``!D@'2P=*>$1[1(-">D0#T`5+TU@#L1A'<$<`
MO[9Z``"T>@``,'D```P!```(2`E+>$1[1!L:V0\'2@'KHP%)$'I$`]`%2]-8
M`[$81W!'`+^,>@``BGH``/QX```L`0``3_2`7!"UK>L,#,SX^`\.2PY,>T0;
M>'Q$H[D-2^-8([$,2WM$&&C_]Q3N__>Y_PI+XU@;L0E(>$3_]V#M`2((2WM$
M&G`0O0"_2GH``,9X```D`0``]GD```@!``"V9```''H``$_T@%P(M:WK#`S,
M^/@/!TL'2GM$FU@KL09)!TAY1'A$__?J[;WH"$">YP"_9G@``"@!``#@>0``
M:F0``$_T@%PMZ?A#K>L,#,SXX`\?2X!&>T0`*#;0'DJ;6-/X`)"Y\0`/,=`%
M>`]&`"T8OSTM%+\!)0`E$]'9^`!`;+%.1BI&048@1O_W2NT0N6-=/2L0T%;X
M!$\`+/+1($:]Z/B#!485^`$_`"L8OSTK^=&EZP@%X>>FZPD&`36V$"Q$/F`@
M1KWH^(,$1N?G3$;EYRAX```<`0``3_2`7!"UK>L,#,SX6`\72A=+>D2HL--8
M:48;:">33_```P1&__?([:"Y!)L#]'!#L_4@3QB_L_6`3PW0#4H,2WI$TU@:
M:">;6D!/\``#"]$HL!"]`"#QYP(A($;_]YKLL/J`\$`)Z>?_]]+MDG<``"`!
M``!D=P``3_2`7/"UK>L,#,SX2`\T2C1+>D336*FP&V@GDT_P``,0L0-X!$9;
MN2]*+DMZ1--8&F@GFUI`3_```T_1*;#PO?_W3NP%1@`H[M`H1O_WENR8L\-\
M`/$3!BXK`M%S>``K\]##?"XK+]`@1O_WD.T'1C!&__>,[3A$`C#_]Y[L,T8&
M1AI)(D9Y1/_W;NTP1FE&__<\[0$P,$8%T`2;`_1P0[/U@$\7T/_W@NPP1O_W
M0NTH1O_W9.P`*,O1*$;_]Z#L($;_]Q[MK^=S>"XKS-&S>``KNM#(Y__WD__F
MY__W7.T:=P``(`$```!W``!B(0``3_2`7"WI\$>MZPP,S/C8#PQ&5DI62WI$
MTUB"L!MH`9-/\``#"W@%1CTK"+\!-"!&__<T[6E&!D8H1O_WX?Y-3X%&?T0`
M*%30__<H[89"1]D`FT_J@PA(2_]8*W@`*QB_/2L4OP$C`",'T"M&$_@!+P`J
M&+\]*OG16QNP'!A$/FC_]R+L1O@(`.BQ*$8[:%/X"!`0^`$[/2L8OP`K"W`)
MT$H<$/@!.Q%&/2L8OP`K`O@!._;1/2,*1@MP%/@!.P+X`3\`*_G1+4HI2WI$
MTU@::`&;6D!/\``#1=$"L+WH\(<)\?\Y%/@!.PGX`3\`*_G1Z><A2_]8U_@`
M@-CX`#![LT-&4_@$+TE&"?$!"0`J^-$#,8D`&DIZ1!-HN[D!(PA&$V#_]]+K
M@D8`*,S0049/ZHD(0D;_]\[KQ_@`H``CS?@`D`GQ`0E*^"DPAN=`1O_W8NN"
M1CA@`"BUT$_JB0CMYYE&""'6Y__WH.P`OR9V```@`0``^G4``!P!``!R=0``
MPG8``$_T@%PPM:WK#`S,^.`/$D@=[G!/>$0`:!%*$DEZ1%%8A;`*1@.1$$L0
M22!8>T1Y1/_W5.P)2``E>$0`:`Q+#4H-27M$(%AZ1,WI`#5Y1/_W..L%L#"]
M`+^X=0``E'4``)QT```P`0``^%\``$X?```^(@``FP\``$P?```0M`Q)#$K?
M^#3`>40):'I$'>YP#U+X#$!`6")&"$L)28.P>T1Y1`&4`[!=^`1+__<5O`"_
M1G4``"YT```P`0``AE\``-P>``!/](!<<+6MZPP,S/@``*SU@%S,^```3/@H
M##!*,$NM]0!=AK!Z1--8#?4`410Q&V@+8$_P``/_]_KJ*DPJ2GQ$`ZX#1GI$
M0?(!`3!&`)3_]]#J0?(!`T(<FD(YV`$P.-`-]8!5$#5/](!2*48P1O_W<.L$
M'BW;8!S_]P+K`T9`LZA"`M("&95"(M.K0AW80?(!`I1"'-@B1AA&*4;_]\[K
M`"(#1@)5$4D-2GE$#?4`4(I8%#`1:`)H44!/\``""M$81@WU`%T&L'"]*AF3
M0M[2_]X`(^?G__?$ZP"_T',``"`!``"Z'@``J!X``$IS``#_]X:_3_2`7"WI
M\$^MZPP,S/@``$SXT`Q@3*WUA5U@2H.P?$0%1E](HE@-]853`J\.1GA$.48$
M,Q)H&F!/\``"__="_2\A!$8H1O_W[.K`L55(*49X1/_W-_XH1E-*4$MZ1`WU
MA5'36`0Q&F@+:%I`3_```T#PCX`-]85=`["]Z/"/,$;_][#J24EY1/_W4NN"
M1@`HW-#?^!R!FO@`,`WQJ`GX1*GQ!`8`*U'0++%11B!&__=*Z@`H/M!01O_W
M4NL"1D,>4T2:18-&/K\`(5)$"O$!`P/3"^"30A%P!-`2^`'-O/$O#_?04$;_
M]SSK@T8H1O_W..M81`$PL/6`7Z?2W_BTP%-&_$1"1D_T@%$P1LWI`,7_]_3I
M`3"P]8!?/-@Y1C!&__?>ZC"Y6?B0/`/T<$.S]0!/&=`@20`@>43_]_KJ@D8`
M*(/0FO@`,``KK='<L2-X+BL%T-_X9*!/\`$+^D3%YV-X`"OFT/7G`2$P1O_W
MP.D`*-_1$D@Q1GA$__>C_3!&__<PZFCGW_@\H$_P`0OZ1*SG__?LZO_>XG(`
M`"`!``#>'0``R!T``*1R``"B'0``CAT``#(=``#P'```K!P``*`<``!Z'```
M3_2`7!"UK>L,#,SX^`\O(01&__?PZ0"Q1!P@1KWH$$#_]_JY3_2`7#"UK>L,
M#,SX``!,^!@,.DHZ2ZWU@%UZ1(.P#?6`4=-8!#$;:`M@3_```P`H.M`#>`5&
MN[/_]YSJ`3"P]8!?1]@!K"E&($;_][SI($;_]Y#J`3@@1*!""-D`(@+@H$)"
M<`/0$/@!.2\K^-`O(2!&__>NZ7BSH$*$OP`C`W`@1O_WNND?2AU+>D0-]8!1
MTU@$,1IH"VA:0$_P``,KT0WU@%T#L#"]%TH52WI$#?6`4=-8!#$::`MH6D!/
M\``#&M$22'A$#?6`70.PO>@P0/_WD+D`(-;G#4H)2WI$#?6`4=-8!#$::`MH
M6D!/\``#`M$(2'A$YN?_]T+J^G```"`!``"*<```:'```%@;```X<```*!L`
M`$_T@%QPM:WK#`S,^.@/S$K,2WI$S$W36,Q.@K!]1!MH`9-/\``#?D1L1B%&
M,$;_]\?[L+'&2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P
M1O_WL?L`*.C1O$Y^1"%&,$;_]ZG[L+&W2P"8ZU@9:`'K@`-::$'X("``*N_0
M!#-::$/X!"L`*OK1(48P1O_WD_L`*.C1KDY^1"%&,$;_]XO[L+&H2P"8ZU@9
M:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W=?L`*.C1H$Y^1"%&
M,$;_]VW[L+&92P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P
M1O_W5_L`*.C1DDY^1"%&,$;_]T_[L+&*2P"8ZU@9:`'K@`-::$'X("``*N_0
M!#-::$/X!"L`*OK1(48P1O_W.?L`*.C1A$Y^1"%&,$;_]S'[L+%[2P"8ZU@9
M:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W&_L`*.C1=DY^1"%&
M,$;_]Q/[L+%L2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P
M1O_W_?H`*.C1:$Y^1"%&,$;_]_7ZL+%=2P"8ZU@9:`'K@`-::$'X("``*N_0
M!#-::$/X!"L`*OK1(48P1O_WW_H`*.C16DY^1"%&,$;_]]?ZL+%.2P"8ZU@9
M:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_WP?H`*.C13$Y^1"%&
M,$;_][GZL+$_2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P
M1O_WH_H`*.C1/DY^1"%&,$;_]YOZL+$P2P"8ZU@9:`'K@`-::$'X("``*N_0
M!#-::$/X!"L`*OK1(48P1O_WA?H`*.C1,$@A1GA$__=^^@%&&+$M2'A$__=X
M^RQ((49X1/_W<_H!1ABQ*DAX1/_W;?LI2"%&>$3_]VCZ`4:PL29(>$3_]V+[
M)4H12WI$TU@::`&;6D!/\``#%=$A22)(>41X1`*PO>AP0/_W3[L?2"%&>$3_
M]TKZ`48`*.30'$AX1/_W0_O?Y__WE.CJ;P``(`$``.!O```.&P``'`$``-P:
M``"H&@``>!H``$0:```8&@``>!D``*P9``!\&0``3!D``)08``#>&```NA@`
M`-P8``#D&```YA@``!(8``#\;```X!@``$88``"Z&```1!@``$_T@%P`M:WK
M#`S,^/`/$TH32WI$$TB#L--8:49X1!MH`9-/\``#__?W^4"Q`'@`*!B_,"@,
MOP$@`""`\`$`"DH'2WI$TU@::`&;6D!/\``#`M$#L%WX!/O_]S+H0FP``"`!
M``"T%P``$FP``$_T@%P/M`"UK>L,#,SX\`\+20Q+>43+6(.P&V@!DT_P``,$
MJE+X!!L'2PA(>T0`DAM8&&C^]U;O_R#^]YSO`+_4:P``(`$``+QK``#\````
M3_``#"WI\$=/](`^K>L,#*SK#@ZL]8!<S/@``/1%^=%.^#@,`B%`34!,K?6`
M/8:P?40L60WU@#8D:'1A3_``!``B`",`D8!&_O>\[@$X8?$`!_H7@.KG<YL:
MF[)30)L:!O$4!F+K`@+&&F?K`@<`+TO;3_`("0.MP/(!"0`A,D8[1D!&`)'^
M]Y[NL?'_/PB_L/'_/T'02D8I1D!&_O=:[T,<-M`'*";9"#@L&"/2W_B`H/I$
M`N`!/*Q"'-,((E%&($;^]TKN`"CUT60;H!E'Z^1Q&$H52WI$#?6`---8%#0:
M:"-H6D!/\``#&M$-]8`]!K"]Z/"'MO6`-F?Q``>W\?\_"+\6]8`_N-%/\/\P
M`4;?YPE(>$3_]TO_"$AX1/_W1__^]W#O`+]H:P``(`$``"9L``#":@``D!8`
M`'@6``!/](!<"+6MZPP,S/CX#_[W8._^][[N`+$`:`B]3_2`7/"UK>L,#,SX
MV`\D2B1.)4MZ1(6PTUA^1`5&`JDP1AMH`Y-/\``#__?I^!"Q`W@$1HNY'4H;
M2WI$TU@::`.;6D!/\``#*-$I1AA(>$0%L+WH\$#_]].Y*$;^]Q[O!T8@1O[W
M&N\X1`(P_O<L[A!+$4DJ1GM$>40`E`1&_O?\[@Y*"$MZ1--8&F@#FUI`3_``
M`P2_(48P1MG0_O<$[RAJ```Z%@``(`$```)J```&%@``[A0``/`4``"V:0``
M3_2`7"WI\$^MZPP,S/C`#L>P#?'("M1&W_@(%-_X"$3?^`@D>42*6'Q$!/$,
M`P3Q&`XLK1)H19)/\``"!9"3Z`<`A>@'`+[H#P"LZ`\`GN@#`#`T#?&\"8SH
M`P"4Z`<`B>@'`/)(W_C,@P:N,49X1/A$__=E^""Q`W@$1@`K0/!6@?[WN.[^
M]Q;N`"@`\)*`!V@`+P#PCH`X1O[WH.Y```$P_O>R[3IX!$:!1EJQW_B(L_M$
M($991O[W?NX7^`$O`C0`*O;1W4AX1`+@6O@$#XBQ,4;_]S3X!$8`*/;0`W@`
M*_/0__=X^``H[]`@1O[WN.T$1GBY5?@$2V2Q(W@`*P#P`8$@1O_W9_@`*.[1
M5?@$2P`L\M$@1O[W8.X%1DA&_O=<[@5$!?($12A&_O=L[<WX!)"!1L)+PDE[
M1`"3PDLB1GM$>43^]SCN3_3@<4A&_O<0[@$P!='^]P;N`&@1*$#PV(`Q1DA&
M_O<2[@1&`"@XT+9(!9JV25CX``!+1A)H`&AY1/[WQNT`);)*ITMZ1--8&FA%
MFUI`3_```T#P.X$H1D>PO>CPC_[W6NT'1@`H0/"K@%GX!`M8L3%&_O?`_P`H
M]]`#>``K[M%9^`0+`"CST0T@_O<8[9]/4R($1H%&?T1DYS-I`_1P0[/U@$_`
MT;=I_O<`[H="N]$S:</S"`.S]>!_M=$H1O[W_NP%1I-(,49X1/[WE/\!1@`H
M`/"9@`6;&&C_]RKZ@D8`*`#PD8!01O[WU.T#*(!&$-F(200X4$1Y1/[WO.Q(
MN;CQ!`\`\,V`T$08^`4\+RL`\,>`@4@Q1GA$_O=L_R"Q`W@P*QB_`"L&T0`A
M4$;^]_CL!D8`*&O1>4EY2'E$>$3_]UGX_O>2['=*=TMX27I$W_C@@7A/>$[-
MZ0`">T1*1BA&>43^]X3M^$1_1'Y$$N#^]U;M`V@1*Q31_O=V[(1&`31#1DI&
M.48H1LWI`4;-^`#`_O=L[4_TX'$H1O[W1NT!,.702$;^]TCM9$@I1GA$__<A
M^"A&__<>_D'G'$8%Y_[W:.U```$PQN9-206:6/@!0%M)$FA+1@"0>40@:/[W
M].PLY__W!_Y72CU+>D336!IH19M:0$_P``-GT2!&1["]Z/!/_O>%O`6;T_@`
MH&KG__=#_;'Q``@'1HW;3_``"K#Q"@)H\0`#,$;-^`"@#?'@"_[W%.P&(C!&
M64;^]]CL!BA%T4_TAD,XFL3R03.:0G_T<J]$\DA3N_@$()I"?_1KK[?Q,@)H
M\0`#,$;-^`"@.JS^]_3K*"(P1B%&_O>X["@H)=$Q2C%+,DEZ1`&2*$9*1@"4
M>T1Y1(WX$*'^]^CL@.<%FU]H`"\_]#2O.$;^]_#L`RA_]BZO)TD$.#A$>43^
M]]KK`"@(O[I&(^?^]^CL(DAX1/_WN?P`OUAI``"4:@``(`$``!H4```,:0``
M^A0``'P4``"&%```<!0``&X3``#\````@A0``.YG``#$$P``1A0``!X4``"6
M$@``[A(``'`2``"L%```"A(``.`3``#^$0``Z!,``(X4``"0$0``I!(``$9F
M``!P$P``TA```)P2``!@$@``5!(``$_T@%SPM:WK#`S,^.`/;TIO2WI$TUB#
ML!MH`9-/\``#8$L=[G!/>T0;:&Y&Y5AI2)7X:#`Q1GA$A?AI,/[W+/X0L0-X
M,2MXT/_W1OI62WM$&VCE6&!)*$8#(P$B>43^]\3K!49PL5%+`FE[1!MH$6A:
M2N!8>D3^]\3K*VD9:(MH6P)OU$I(5DEX1`!H`R,!(B!8>43^]ZCK!49XL5%(
M,49X1/[W^?T"1@`H2M!!2REI>T0;:`EHX%C^]Z+K/DM*27M$&VCE6`$B>40H
M1O[W].I&2@%&>D0H1O[WDNLW2P`B>T0;:$)(XU@Q1GA$@_AI(/[WTOT_3'Q$
MH&"@L4_TX''^]^3K0QP1*!B_`2M`V#I*+TMZ1--8&F@!FUI`3_```S31`[#P
MO6!H__<6_:!@`"CDT3)(>$3^]]CJ0W@`*XG0@N?^]\W_!T:8L1U+*FE[1!MH
M$6@"1N!8_O=2ZSA&_O>^ZZOG%TM[1!MHX%C^]^SJB.<52R)*>T0;:'I$*6E2
M:`EH$FC@6/[W/.N7Y_[WV.L<2@-&'$AZ1-+I`1)X1`EH_O>BZL)E``":90``
M?F4``&!E```X90``*&4```AE``":9```@F0``')D``#"9```(`$``/X/``"L
M$0``F!$``((1``!,#P``4!$``%P1``#V#@``>F4``,)C```$$0``]F0``-ID
M``#`$```3_2`7#"UK>L,#,SXZ`\I2BE+>D0$1BE(@[#36&E&>$0;:`&33_``
M`_[W,/UPL0-X`"L8OS`K#+\!(P`C@_`!`P`L#+\`(P/P`0-;N1Q*&DMZ1--8
M&F@!FUI`3_```R?1`[`PO2-X`"OPT"!&__>B^"\A!4;^]X;J`+%%'"A&_O>6
MZA!)!")Y1/[W<.H`*-W1#4H)2WI$TU@::`&;6D!/\``#!=$@1@.PO>@P0/[W
M=KW^]T#KMF(``"`!```F#@``>&(``(8.```T8@```````$_T@%PMZ?!/K>L,
M#,SX,`W?^)0IW_B4.7I$TUBM]2M]&VBIDT_P``,#1@BI`_&`!PI&`":\1@*0
M0#!0Z0)T(PH#]']#)0)#ZA1C"#`%]'\%0^H$8S^Z*T-@1<+I`C968!=@`O$0
M`NC1W>DB0B:;#?&("0.3"IL*KB:O)*T`DP'U`G/-Z049!)<!DS!&`YNA1MWX
ME(#=^)S`W?@DH-WX++#=^)#@#V@#E@>5`>"K1@"6`"70Z0X44/@(;T5G16AQ
M0('J"0%L0'E`5$"$Z@H$\4:>1LL/0^I$`TD8"T,!F4)&@4+@1MI&3_``#`"?
M`V?=T0.>W>D%&0>=,VC5^`#@`Y,$FPAH'&@"FT?VF1*=:-/X`(`I1AU&T_@0
MH-/X&+!?:"YJVVB-"-GX`,``ED7J@W6*Z@L)Q?:"(D7J@74!D0GJ`0E/ZMAF
M`)E&ZD<6@!A`&$;J2!8#F4_JF`.)Z@L)0^J'<S88BNH%!Q;K"08'Z@@'B1B'
MZ@H'$>L+`4/JB'/(&0R9A>H#!XD8-T!O0!'K"@$`Z_9@R1D!Z_!I#IF)&$D9
M@^JV!05`74!/ZK``21D0G8#JM@>M&`?J"0>'ZK8'[1@!Z_EA[1D%Z_%G$IU.
M]J$SK1@%Z[8%@.JY!@Y`1D"M&12>3^JQ`;88,!B!ZKD&/D"&ZKD&!>OW98`9
M`.OU9A:8QO;98X`8`.NY`('JMPD)Z@4)B>H!"1#K"0#=^&"03^JU!1GK`@D9
MZP$!A>JW"0GJ!@F)ZK<)`.OV8!'K"0$!Z_!I&IF)&`'KMP&%ZK8'!T!O0,D9
M`>OY9QR93^JP`(D821F`ZK8%!>H)!87JM@5)&0'K]V4>F8D8`>NV`8#JN08^
M0$9`B1D!Z_5F()E/ZK<'B1@(&(?JN0$I0('JN0%!&!SK`@`!Z_9LA^JU`3%`
M`.NY`'E`3^JV!D$8'NL"`,`9`>O\9X;JM0$!Z@P!@>JU`4$8H!B&ZKP$/$!T
M0`#KM0`!Z_=A`!E/ZK<'`.OQ9"B8A^J\!8`8#4"%ZKP%@!E`&0#K]&4JF(?J
ML0:`&"9`?D``Z[P`@!DLGD_JM`2V&/89A.JQ!R]`A^JQ!P#K]6#V&0;K\&<N
MGK(8A.JU!@+KL0(&0$_JL`$PF&9`DAG`&#*>`!F!ZK4$?$`$&?`8`NOW8H'J
MMP8`Z[4`-)U60`3K\F2`&4_JL@+M&&D8@NJW!C:=9D".&>D8`.OT8#B=`>NW
M`8+JM`<&Z_!F1T!/ZK``R1F`ZK0,.I_M&(SJ!@RM&!7K#`7_&`'K]F&`ZK8,
M!^NT!SR<C.H!#`7K\647ZPP'3^JQ`>08@>JV#"08!^OU8#Z?C.H%#!3K#`3_
M&('JM0P'Z[8'0)Z,Z@`,!.OP9!?K#`=/ZK``]AAV&(#JM0P'Z_1A0I^,Z@0,
M%NL,#$OVW$+_&$2>!^NU!PSK\66`ZK0,C.H!#!?K#`=/ZK$!]A@V&('JM`P'
MZ_5@1I^,Z@4,%NL,#/\82)X'Z[0'#.OP9('JM0R,Z@`,%^L,!T_JL`#V&'88
M@.JU#`?K]&%*GXSJ!`P6ZPP,_QA,G@?KM0<,Z_%E@.JT#(SJ`0P7ZPP'3^JQ
M`?88-AB!ZK0,!^OU8$Z?C.H%#!;K#`S_&%">!^NT!PSK\&2!ZK4,C.H`#!?K
M#`=/ZK``]AAV&(#JM0P'Z_1A4I^,Z@0,%NL,#/\85)X'Z[4'#.OQ98#JM`R,
MZ@$,%^L,!T_JL0'V&('JM`PV&`?K]6!6GXSJ!0P6ZPP&_Q@'Z[0,6)N!ZK4$
MR/8;<D_JL`=$0`;K\&8<ZP0$1^JU`)L8!^JU#%D8,$`$Z_9C6IQ`Z@P`"!BD
M&`3KM04`Z_-D1^JV``?JM@P80%R93^JS`T#J#`!`&4/JM@4#ZK8,B1@E0,D9
M1>H,!5Z?`.OT8&T80^JT`0/JM`R_&`%`!>OP90?KM@=/ZK``8)Y!Z@P!R1E`
MZK0'`.JT#MWXB,&V&"]`]AA'Z@X'OQD<ZP(,`>OU80SKM`Q`ZK4$9)X`ZK4.
M#$!$Z@X$!^OQ9Q3K#`1/ZK$!MA@P&$'JM08!ZK4.W?B8P3Y`1NH.!@3K]V0V
M&!SK`@Q!ZK<``>JW#@SKM0P@0&B=0.H.``;K]&80ZPP`3^JT!*T8:1A$ZK<%
M!.JW#MWXJ,$U0$7J#@5M&!SK`@P`Z_9@#.NW#$3JM@<$ZK8.;)D'0$?J#@<%
MZ_!E%^L,#$_JL`")&`\9#.OU9$#JM@P`ZK8.;ID,Z@4,3.H.#!SK!P>)&`'K
MM@Q`ZK4&`.JU#G"9)D!&Z@X&!^OT9Q;K#`Q/ZK0$B1@.&`SK]V!$ZK4,!.JU
M#G*9#.H'#$SJ#@P<ZP8&B1@!Z[4,1.JW!03JMPYTF05`1>H.!0;K\&85ZPP,
M3^JP`(D8#1D,Z_9D0.JW#`#JMPYVF0SJ!@Q,Z@X,'.L%!8D8`>NW#$#JM@<`
MZK8.)T!'Z@X'%^L,#``G3/+6$WB9!>OT98D83^JT!!'K``D"F`SK]6%$ZK8,
M!.JV#D=@QV!'8<=A#.H%#'J83.H.#!SK"0>`&`#KM@Q$ZK4&!.JU#GR8#D!&
MZ@X&!^OQ9Q;K#`9/ZK$!@!@0ZP0,!NOW9$'JM08!ZK4.?I@^0$;J#@86ZPP,
M@!@`Z[4&0>JW``SK]&6`F@'JMPP@0,SV8B-`Z@P`3^JT!(`9TAB$ZK<&41B"
MFFY`B1G2&`#K]6`"Z[<&A.JU!X2:1T`!Z_!A]AE/ZK``TAB`ZK4'%!F&FD]`
MY!G2&`;K\68"Z[4%@.JQ!XB:=T`$Z_9D[QE/ZK8%TA@6&`?K]&"*FH7JL0=G
M0/<9TA@"Z[$&!^OP88R:A>JT!T=`]AE/ZK``TAA7&0;K\66.FH#JM`9.0+\9
MTA@"Z[0&!^OU9)":@.JQ!V]`]AE/ZK4%TA@7&`;K]&"2FH7JL09F0+\9TA@"
MZ[$&!^OP892:A>JT!T=`]AE/ZK``TAA7&0;K\666FH#JM`9.0+\9TA@"Z[0&
M!^OU9)B:@.JQ!V]`]AE/ZK4%TA@7&)J:!NOT8(7JL09F0+\9TA@"Z[$&!^OP
M89R:A>JT!T=`]AE/ZK``TAB`ZK0'51F>FD]`[1G7&`;K\68'Z[0'H)J`ZK$$
M=$`%Z_9E/QE/ZK8$TA@6&`?K]6"BFH3JL0=O0/<9TA@"Z[$&!^OP80*?"^NQ
M`KIAA.JU!T=`I)KV&0;K\6;2&`*?3^JP`!09"NNV`CIA@.JU!Z::3T#D&=(8
M$NL(`@+KM0.`ZK$"<D";&`&:`I\$Z_9DHABZ8``B`)EZ8@/K]&,+2CM@0!@(
M2WI$.&+36!IHJ9M:0$_P``,#T0WU*WV]Z/"/_?=>[N!A```@`0``;E@``$_T
M@%P(M:WK#`S,^/@/@"#]]U[MG^T/>X#M`'N?[0][@.T">Y_M#WN`[01[G^T/
M>X#M!GN?[0][@.T(>Y_M#WL`(H#M"GN`[0Q[@F<(O0"_K_,`@`$C16<`````
MB:O-[P````#^W+J8`````'94,A``````\.'2PP```````````````$_T@%PM
MZ?!'K>L,#,SXX`\51@9&`".$:HI&T.D,(03KQ0>G0O1J3^KE<'/K!`0"T@$R
M0?$``<;I"G-K#T/JP`.;&$'K4'&P;S-C<6,&\3@(Z+'`\4`$!O$X"*Q"0$2H
MORQ&4$52T@,9FD4HOPKK!`=&TU%&(D;]]\CMLV\C1$`KLV<WT3!&__>?^KI&
M+1L_+2/=5$8&\7@)"O%`!Z!%*]),12W3ND9#1@3Q0`[4^`#`8&BA:.)H$#1T
M1</X`,!88)E@VF`#\1`#\-$P1D`]__=[^C\M!_%`!^#<T$41TP/9"NL%`YA%
M"],J1E%&0$;]]XSMM6>]Z/"'ND;4V;A%TM+_W@CK!0.:1>[2_]X*ZP0'K]FX
M0JW2_]Y/](!<+>GP0:WK#`S,^.@/3_"`#(MJ`?$X!Y/Z@_C#\\4#"FL'^`/`
M`3,X*PQ&!486ND7=`"'#\4`"^!C]]VCL($;_]S7Z."(`(3A&_?=@["!&Q.D<
M:/_W*_KC>"!&*W!CB&MP(V@;"JMP(VCK<.-Z*W%CB6MQHV@;"JMQHVCK<>-\
M*W)CBFMR(VD;"JMR(VGK<N-^*W-CBVMSHVD;"JMSHVGK<Y3X(S`K=&.,:W0C
M:AL*JW0C:NMTO>CP0?WW]KP`(?@8P_$X`OWW(NS`YP"_`;6]Z`%`<$<^````
M00````P```!!````$0```$$````G````00```#8```!!`````P```$$````&
M````00```!4```!!````#P```$$````.````00```"8```!!````$P```$$`
M```I````00````(```!!````&0```$$````*````00````L```!!````````
M```````E<R\E<P```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E
M<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]4
M14U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,
M24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,
M25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?
M0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2
M````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%
M04X`````,0```&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9`!,1%],24)2
M05)97U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES
M('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R
M871I;VXI"@``4$%42`````!P87)L`````"YP87(`````<VAO<G0@<F5A9```
M)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE
M=25S`````!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@``
M```Q+C`V,P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!54T52`````%5315).
M04U%`````%1%35!$25(`5$U0`"]T;7``````979A;"`G97AE8R`O=7-R+V)I
M;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-
M04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"
M14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E
M=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@
M-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P
M87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T
M("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@
M/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C
M($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL
M92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@
M)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H
M;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T
M=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R
M;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E
M36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D
M9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB
M.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?
M=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I
M"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G
M"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C
M;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C
M;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E
M<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT
M97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!
M4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<
M)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N
M86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q
M6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S
M=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&
M2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F
M<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@
M87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G
M:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S
M(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%2
M7TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*
M;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B
M*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M
M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H
M*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE
M(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*
M;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U
M;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D
M;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M
M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES
M=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;
M56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@
M)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E
M9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C
M86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E
M='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D
M36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I
M;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB
M=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN
M9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*
M?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)
M3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@
M)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN
M<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF
M("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N
M9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL
M87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@
M("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM
M>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T
M92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@
M8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I
M<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*
M=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R
M"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H
M:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8[
M"GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?
M:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB
M<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H
M($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@
M(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?
M87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*
M96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF
M("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E
M<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@
M9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?
M;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES
M=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN
M8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]
M"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B
M73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T
M82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O
M+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@
M+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T
M(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H
M+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U
M;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A
M=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*
M24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R
M96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?
M1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D
M97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L
M;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD
M;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM
M>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N
M92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X
M<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@
M0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE
M<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B
M:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O
M;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT
M(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F
M:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C
M(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D
M;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER
M("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y
M(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@
M)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D
M,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE
M*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S
M<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN
M97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT
M7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL
M(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N
M=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U
M9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G
M/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D
M(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE
M(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT
M*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT
M9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C
M;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%
M('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI
M.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A
M;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E
M9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN
M97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E
M96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*
M?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE
M7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M
M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C
M:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL
M("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F
M<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@
M)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O
M<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P
M97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!0
M05(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M(#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@
M<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M
M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA
M;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA
M;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM
M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]4
M14U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US
M(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;
M4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES
M=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C
M=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M
M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG
M('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E
M<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E
M4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z
M.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P
M871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?
M;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E
M<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN
M9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!
M4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@
M<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![
M(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI
M=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z
M.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I
M<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]
M"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@
M/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R
M;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN
M3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*
M96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D
M96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!
M3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M
M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S
M"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*
M;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII
M9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*
M+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A
M8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE
M7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD
M8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A
M8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD
M<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N
M86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B
M)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@
M)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H
M+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S
M*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E
M;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!
M345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2![
M"FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF
M("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P
M<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY
M("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S
M>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y
M<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D
M<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<
M12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-
M4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.
M5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B
M?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6
M>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B
M(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT
M("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U
M8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@
M9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB
M97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A
M<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E
M<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T
M;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]2
M13HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]2
M13HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.
M1%]?"@!P97)L>'-I+F,`````0T%#2$4``#X```!!````#````$$````1````
M00```"<```!!````-@```$$````#````00````8```!!````%0```$$````/
M````00````X```!!````)@```$$````3````00```"D```!!`````@```$$`
M```9````00````H```!!````"P```$$`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!)%@``Y14```$````6`P``
M`0```"$#```=````=00```P```!9$```#0```.DX```9````S(T``!L````$
M````&@```-"-```<````!````/7^_V]P`0``!0```/P(```&````7`(```H`
M``"3!```"P```!`````5``````````,```#$C@```@```-@!```4````$0``
M`!<```"`#@``$0```)`-```2````\````!,````(````'@````@```#[__]O
M`0``"/K__V\0````````````````````````````````````````````````
M`````````-2-`````````````&`0``!@$```8!```&`0``!@$```8!```&`0
M``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!``
M`&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```
M8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@
M$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0
M``!@$```8!```&`0``!@$```8!```&`0``!@$```21,`````````````Z3@`
M````````````61``````````````````````````````````````````````
M````````````D```"E!!4BYP;0H`````N#P``,PY````````C#H``)`Z``"L
M/```U#D``+0\````````F#P``*`\````````P#P``$=#0SH@*$%L<&EN92`Q
M,RXR+C%?9VET,C`R-#`S,#DI(#$S+C(N,2`R,#(T,#,P.0!!,@```&%E86)I
M``$H````!3<M00`&"@=!"`$)`@H$$@03`10!%0$7`Q@!&@(<`1X"(@$`+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`
M+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T
M<FEB=71E<P``````````````````````````````````````````````````
M````"P````$````"````-`$``#0!```8```````````````!`````````!,`
M```'`````@```$P!``!,`0``)```````````````!``````````F````]O__
M;P(```!P`0``<`$``.P````$``````````0````$````,`````L````"````
M7`(``%P"``"@!@``!0````,````$````$````#@````#`````@```/P(``#\
M"```DP0``````````````0````````!`````"0````(```"0#0``D`T``/``
M```$``````````0````(````20````D```!"````@`X``(`.``#8`0``!```
M`!$````$````"````%(````!````!@```%@0``!8$```"```````````````
M`@````````!-`````0````8```!@$```8!```.0"``````````````0````$
M````6`````$````&````2!,``$@3``"@)0`````````````(`````````%X`
M```!````!@```.@X``#H.```"````````````````@````````!D`````0``
M``(```#P.```\#@``.1!``````````````0`````````;`````$````"````
MU'H``-1Z```$```````````````$`````````'8````.`````P```,R-``#,
M?0``!```````````````!`````0```""````#P````,```#0C0``T'T```0`
M``````````````0````$````C@````8````#````U(T``-1]``#P````!0``
M```````$````"````)<````!`````P```,2.``#$?@``/`$`````````````
M!`````0```"<`````0````,`````D````(```$0```````````````0`````
M````H@````@````#````1)```$2````L```````````````$`````````*<`
M```!````,`````````!$@```,0```````````````0````$```"P`````P``
M<```````````=8```#,```````````````$``````````0````,`````````
<`````*B```#````````````````!````````````
